@@ -1,4 +1,4 @@
-VERSION = (1, 7, 1)
+VERSION = (1, 7, 2)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -58,5 +58,15 @@ def ensure_completely_loaded(force=False):
             except AttributeError:
                 pass
 
+    # Calls to get_models(...) are cached by the arguments used in the call.
+    # This cache is normally cleared in loading.register_models(), but we
+    # invalidate the get_models() cache, by calling get_models
+    # above before all apps have loaded. (Django's load_app() doesn't clear the
+    # get_models cache as it perhaps should). So instead we clear the
+    # get_models cache again here. If we don't do this, Django 1.5 chokes on
+    # a model validation error (Django 1.4 doesn't exhibit this problem).
+    # See Issue #323 on github.
+    loading.cache._get_models_cache.clear()
+
     COMPLETELY_LOADED = True
     return True
